import { defineColumns } from '@bole-core/components';
import { TempFolderPath } from './enum';

export enum FourStreamsMaterialFileBusinessTypeEnum {
  /** 园区入驻协议 */
  ParkEnterPactUrl = 10,
  /** 企业完税证明（盖章） */
  RatePaymentFileUrl = 20,
  /** 企业缴税明细汇总表（盖章） */
  TaxSubFileUrl = 30,
  /** 企业营收利润表 */
  OperateProfitesUrl = 40,
  /**
   * 入驻关联说明
   * @deprecated 已经不用了
   */
  EnterRelateUrl = 50,
  /** C端个税完税证明 */
  PersonTaxRatePayUrl = 60,
  /** C端完税说明 */
  PersonTaxInstructUrl = 70,
}

export const FourStreamsMaterialFileBusinessTypeEnumText = {
  [FourStreamsMaterialFileBusinessTypeEnum.ParkEnterPactUrl]: '园区入驻协议',
  [FourStreamsMaterialFileBusinessTypeEnum.RatePaymentFileUrl]: '企业完税证明(盖章)',
  [FourStreamsMaterialFileBusinessTypeEnum.TaxSubFileUrl]: '企业缴税明细汇总表(盖章)',
  [FourStreamsMaterialFileBusinessTypeEnum.OperateProfitesUrl]: '企业营收利润表',
  [FourStreamsMaterialFileBusinessTypeEnum.EnterRelateUrl]: '入驻关联说明',
  [FourStreamsMaterialFileBusinessTypeEnum.PersonTaxRatePayUrl]: 'C端个税完税证明',
  [FourStreamsMaterialFileBusinessTypeEnum.PersonTaxInstructUrl]: 'C端完税情况说明',
};

export const FourStreamsMaterialFileBusinessTypeEnumKey = {
  [FourStreamsMaterialFileBusinessTypeEnum.ParkEnterPactUrl]: 'parkEnterPactUrl',
  [FourStreamsMaterialFileBusinessTypeEnum.RatePaymentFileUrl]: 'ratePaymentFileUrl',
  [FourStreamsMaterialFileBusinessTypeEnum.TaxSubFileUrl]: 'taxSubFileUrl',
  [FourStreamsMaterialFileBusinessTypeEnum.OperateProfitesUrl]: 'operateProfitesUrl',
  [FourStreamsMaterialFileBusinessTypeEnum.EnterRelateUrl]: 'enterRelateUrl',
  [FourStreamsMaterialFileBusinessTypeEnum.PersonTaxRatePayUrl]: 'personTaxRatePayUrl',
  [FourStreamsMaterialFileBusinessTypeEnum.PersonTaxInstructUrl]: 'personTaxInstructUrl',
} as const;

export enum ApplyTransferFileBusinessTypeEnum {
  /** 财政拨付凭证*/
  FinanceToFileUrl = 100,
  /** 平台拨付凭证*/
  TransferToFileUrl = 110,
}

export const ApplyTransferFileBusinessTypeEnumText = {
  [ApplyTransferFileBusinessTypeEnum.FinanceToFileUrl]: '财政拨付凭证',
  [ApplyTransferFileBusinessTypeEnum.TransferToFileUrl]: '平台拨付凭证',
};

export const ApplyTransferFileBusinessTypeEnumKey = {
  [ApplyTransferFileBusinessTypeEnum.FinanceToFileUrl]: 'financeToFileUrl',
  [ApplyTransferFileBusinessTypeEnum.TransferToFileUrl]: 'transferToFileUrl',
} as const;

export enum TransferFileEnumInRewardGrand {
  /** 财政拨付凭证*/
  FinanceFileUrl = 200,
  /** 平台拨付凭证*/
  SettleFileUrl = 210,
}

export const TransferFileEnumInRewardGrandText = {
  [TransferFileEnumInRewardGrand.FinanceFileUrl]: '财政拨付凭证',
  [TransferFileEnumInRewardGrand.SettleFileUrl]: '平台拨付凭证',
};

export const TransferFileEnumInRewardGrandKey = {
  [TransferFileEnumInRewardGrand.FinanceFileUrl]: 'financeFileUrl',
  [TransferFileEnumInRewardGrand.SettleFileUrl]: 'settleFileUrl',
} as const;

export const BaseDeclareEnterpriseTableViewColumns = defineColumns([
  {
    id: '1',
    enCode: 'userName',
    name: '帐号',
  },
  {
    id: '2',
    enCode: 'enterpriseName',
    name: '企业名称',
  },
  {
    id: '3',
    enCode: 'societyCreditCode',
    name: '信用代码',
  },
  {
    id: '4',
    enCode: 'contactPhone',
    name: '电话',
  },
  {
    id: '5',
    enCode: 'authType',
    name: '企业类型',
  },
  {
    id: '6',
    enCode: 'licenseUrl',
    name: '营业执照',
  },
  {
    id: '7',
    enCode: 'bankAccountInfo',
    name: '基本户信息',
  },
]);

type UseAddRewardApplyStep3ColumnsOptions = {
  suportEnterpriseUpload: Ref<boolean>;
  baseColumns?: API.ModuleColumnDto[];
};

export function useAddRewardApplyStep3Columns({
  suportEnterpriseUpload,
  baseColumns = BaseDeclareEnterpriseTableViewColumns,
}: UseAddRewardApplyStep3ColumnsOptions) {
  const addRewardApplyStep3Columns = computed(() =>
    defineColumns(
      [
        ...baseColumns,
        suportEnterpriseUpload.value && {
          id: '9',
          enCode: 'applyAmount',
          name: '申报金额',
        },
      ].filter(Boolean)
    )
  );

  return { addRewardApplyStep3Columns };
}

export const BountyBatchApplyTransferTemp = `${TempFolderPath}/%E5%85%A5%E8%B4%A6%E6%A8%A1%E6%9D%BF.xlsx`;
